/*
 * Copyright 2007 Roberto Fasciolo
 * 
 * This file is part of vsitegen.
 * 
 * vsitegen is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * vsitegen is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with vsitegen; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package net.robyf.vsitegen.engine;

import java.io.PrintWriter;
import java.io.StringWriter;

import org.junit.Assert;

import net.robyf.vsitegen.model.Navigation;

import org.junit.Test;

public final class TemplateEvaluatorTest {

    private static final String PROJECT_NAME = "Test project";

    private final Navigation navigation = Navigation.build(this.getClass()
            .getResourceAsStream("/navigation.xml"));

    private final TemplateEvaluator evaluator = new TemplateEvaluator(PROJECT_NAME,
                                                                      this.navigation,
                                                                      "test/resources");

    @Test (expected = EvaluatorException.class)
    public void testEvaluate_unexistantTemplate() {
        this.evaluator.evaluate("unexistant.vtl", null, null);
    }

    @Test
    public void testEvaluate_firstTemplate() {
        String result = this.evaluator.evaluate("first.vtl", null, null);
        Assert.assertEquals("Hello world!", result);
    }

    @Test
    public void testEvaluate_projectNameTemplate() {
        String result = this.evaluator.evaluate("projectName.vtl", null, null);
        Assert.assertEquals("This is project: " + PROJECT_NAME, result);
    }

    @Test
    public void testEvaluate_navigationTemplate() {
        StringWriter strwriter = new StringWriter();
        PrintWriter writer = new PrintWriter(strwriter);
        writer.println("-- Documentation");
        writer.println("current page Overview");
        writer.println("page Dependencies");
        writer.println("-- Project reports");
        writer.println("link JavaDocs");
        writer.println("link Sources");
        writer.println("link CheckStyle report");
        String expected = strwriter.toString();

        String result = this.evaluator.evaluate("navigation.vtl", "overview", null);
        Assert.assertEquals(expected, result);
    }

}
