/*
 * Copyright 2007 Roberto Fasciolo
 * 
 * This file is part of vsitegen.
 * 
 * vsitegen is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * vsitegen is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with vsitegen; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package net.robyf.vsitegen.model;

import org.junit.Assert;

import org.junit.Test;

public final class NavigationTest {

    @Test
    public void testBuild() {
        Navigation navigation = Navigation.build(this.getClass()
                .getResourceAsStream("/navigation.xml"));
        Assert.assertNotNull("navigation null", navigation);
        Assert.assertEquals("section list size", 2, navigation.getSections().size());

        Section section1 = navigation.getSections().get(0);
        Assert.assertEquals("section 1 id", "documentation", section1.getId());
        Assert.assertEquals("section 1 label", "Documentation", section1.getLabel());
        Assert.assertNotNull("section 1 elements", section1.getElements());
        Assert.assertEquals("section 1 elements size", 2, section1.getElements().size());

        Assert.assertTrue("section 1 element1 isPage", section1.getElements().get(0).isPage());
        Assert.assertFalse("section 1 element1 isLink", section1.getElements().get(0).isLink());
        Page page = (Page) section1.getElements().get(0);
        Assert.assertEquals("page1 id", "overview", page.getId());
        Assert.assertEquals("page1 label", "Overview", page.getLabel());
        Assert.assertEquals("page1 file", "index", page.getFile());

        Assert.assertTrue("section 1 element2 isPage", section1.getElements().get(1).isPage());
        Assert.assertFalse("section 1 element1 isLink", section1.getElements().get(1).isLink());
        page = (Page) section1.getElements().get(1);
        Assert.assertEquals("page2 id", "dependencies", page.getId());
        Assert.assertEquals("page2 label", "Dependencies", page.getLabel());
        Assert.assertEquals("page2 file", "dependencies", page.getFile());

        Section section2 = navigation.getSections().get(1);
        Assert.assertEquals("section 2 id", "reports", section2.getId());
        Assert.assertEquals("section 2 label", "Project reports", section2.getLabel());
        Assert.assertNotNull("section 2 elements", section2.getElements());
        Assert.assertEquals("section 2 elements size", 3, section2.getElements().size());

        Assert.assertTrue("section 2 element1 isLink", section2.getElements().get(0).isLink());
        Assert.assertFalse("section 2 element1 isPage", section2.getElements().get(0).isPage());
        Link link = (Link) section2.getElements().get(0);
        Assert.assertEquals("link1 id", "javadoc", link.getId());
        Assert.assertEquals("link1 label", "JavaDocs", link.getLabel());
        Assert.assertEquals("link1 url", "javadocs/index.html", link.getUrl());
        Assert.assertTrue("link1 newWindow", link.isNewWindow());

        Assert.assertTrue("section 2 element2 isLink", section2.getElements().get(1).isLink());
        Assert.assertFalse("section 2 element2 isPage", section2.getElements().get(1).isPage());
        link = (Link) section2.getElements().get(1);
        Assert.assertEquals("link2 id", "sources", link.getId());
        Assert.assertEquals("link2 label", "Sources", link.getLabel());
        Assert.assertEquals("link2 url", "j2h/index.html", link.getUrl());
        Assert.assertTrue("link2 newWindow", link.isNewWindow());

        Assert.assertTrue("section 2 element3 isLink", section2.getElements().get(2).isLink());
        Assert.assertFalse("section 2 element3 isPage", section2.getElements().get(2).isPage());
        link = (Link) section2.getElements().get(2);
        Assert.assertEquals("link3 id", "checkstyle", link.getId());
        Assert.assertEquals("link3 label", "CheckStyle report", link.getLabel());
        Assert.assertEquals("link3 url", "checkstyle.html", link.getUrl());
        Assert.assertFalse("link3 newWindow", link.isNewWindow());
    }

    @Test (expected = IllegalArgumentException.class)
    public void testBuild_noFile() {
        Navigation.build(this.getClass().getResourceAsStream("foo"));
    }

    @Test (expected = ParserException.class)
    public void testBuild_malformed() {
        Navigation.build(this.getClass().getResourceAsStream("/navigation-malformed.xml"));
    }

}
